about summary refs log tree commit diff
path: root/stdlib/tst-strtol-binary-main.c
diff options
context:
space:
mode:
Diffstat (limited to 'stdlib/tst-strtol-binary-main.c')
-rw-r--r--stdlib/tst-strtol-binary-main.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/stdlib/tst-strtol-binary-main.c b/stdlib/tst-strtol-binary-main.c
index f1ed2fde7e..47a208748f 100644
--- a/stdlib/tst-strtol-binary-main.c
+++ b/stdlib/tst-strtol-binary-main.c
@@ -1,4 +1,4 @@
 /* Test strtol functions with C2X binary integers.
    Copyright (C) 2022-2024 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -42,7 +42,7 @@
 #define CHECK_RES(ARG, RES, EP, EXPECTED, EXPECTED_EP)			\
   do									\
     {									\
-      if (TEST_C2X)							\
+      if (TEST_C23)							\
 	{								\
 	  TEST_COMPARE ((RES), EXPECTED);				\
 	  TEST_VERIFY ((EP) == EXPECTED_EP);				\
@@ -1,4 +1,4 @@
-/* Test strtol functions with C2X binary integers.
+/* Test strtol functions with C23 binary integers.
    Copyright (C) 2022-2024 Free Software Foundation, Inc.
    This file is part of the GNU C Library.